@@ -3,7 +3,7 @@ package RestTest::Controller::API::REST;
 use strict;
 use warnings;
 
-use base qw/Catalyst::Controller/;
+use parent qw/Catalyst::Controller/;
 
 sub rest_base : Chained('/api/api_base') PathPart('rest') CaptureArgs(0) {
     my ($self, $c) = @_;
