@@ -2,7 +2,7 @@ package RestTest::Controller::API::REST::Tag;
 
 use strict;
 use warnings;
-use JSON::Syck;
+use JSON::XS;
 
 use parent qw/RestTest::ControllerBase::REST/;
 
@@ -18,19 +18,19 @@ __PACKAGE__->config(
 
     list_prefetch_allows    =>  [ # every possible prefetch param allowed
         [qw/cds/], {  'cds' => [qw/cd_to_producer tags tracks/] },
-		
+
     ],
 
     list_ordered_by         => [qw/tagid/], # order of generated list
     list_search_exposes     => [
         qw/tagid cd tag/,
-        
+
     ], # columns that can be searched on via list
 );
 
 =head1 NAME
 
- - REST Controller for RestTest
+ - REST Controller for
 
 =head1 DESCRIPTION
 
